@@ -1,3 +1,4 @@
+from ipaddress import ip_address
 from typing    import Callable, Dict, List, Optional, Set, Tuple
 from irctokens import Line, build, Hostmask, StatefulDecoder, StatefulEncoder
 from irctokens import hostmask as hostmask_
@@ -194,6 +195,10 @@ class Server(object):
                 channel = self.create_channel(
                     Name(line.params[0], channel_lower)
                 )
+                #TODO: put this somewhere better
+                for mode in self.isupport.chanmodes.a_modes:
+                    channel.list_modes[mode] = []
+
                 self.channels[channel_lower] = channel
 
             self._self_hostmask(line.hostmask)
@@ -533,8 +538,7 @@ class Server(object):
             channel = self.channels[channel_lower]
             if mode in channel._list_modes_temp:
                 mlist = channel._list_modes_temp.pop(mode)
-                for mask in mlist:
-                    channel.add_mode(mode, mask, True)
+                channel.list_modes[mode] = mlist
 
     @line_handler(RPL_BANLIST)
     def _handle_banlist(self, line: Line) -> Emit:
@@ -683,7 +687,10 @@ class Server(object):
                 server  = line.params[5]
             ip:      Optional[str] = None
             if not line.params[3] == "255.255.255.255":
-                ip = line.params[3]
+                try:
+                    ip = ip_address(line.params[3]).compressed
+                except ValueError:
+                    pass
 
             if nickname_lower in self.users:
                 user = self.users[nickname_lower]
